@@ -37,11 +37,14 @@
 //! - Tar
 //! - Png
 //! - Jpg
-//! - Jpg
 //! - 7-zip
 //! - Opus
 //! - Vorbis
 //! - Mp3
+//! - Webp
+//! - Flac
+//! - Matroska (mkv, mka, mks, mk3d, webm)
+//! - Wasm
 //!
 //! ## First Step
 //!
@@ -510,6 +513,32 @@ mod tests {
         test_detect_match("files/test-mp3.mp3", FileType::Mp3);
     }
 
+    #[test]
+    fn test_webp_detect() {
+        test_detect_match("files/rust-logo.webp", FileType::Webp);
+    }
+
+    #[test]
+    fn test_flac_detect() {
+        test_detect_match("files/test-flac.flac", FileType::Flac);
+    }
+
+    #[test]
+    fn test_wasm_detect() {
+        test_detect_match("files/test-wasm.wasm", FileType::Wasm);
+    }
+
+    // False positive - how to avoid?
+    #[test]
+    fn test_flac_txt_detect() {
+        test_detect_match("files/test-flac.txt", FileType::Flac);
+    }
+
+    #[test]
+    fn test_mka_detect() {
+        test_detect_match("files/test-mka.mka", FileType::Matroska);
+    }
+
     #[test]
     fn test_txt_no_match() {
         test_detect_no_match("files/text");
@@ -600,6 +629,11 @@ mod tests {
         b.iter(|| test_detect("files/test-0.tar"))
     }
 
+    #[bench]
+    fn bench_rar_sfx_detect(b: &mut Bencher) {
+        b.iter(|| test_detect("files/hello-world.exe"))
+    }
+
     fn detect_rar() -> Result<(), std::io::Error> {
         let f = OpenOptions::new()
             .read(true)
