@@ -63,6 +63,18 @@ impl TestResult {
             self | other
         };
     }
+
+    fn and<F>(self, other: F) -> TestResult
+    where
+        F: FnOnce() -> TestResult,
+    {
+        return if self == TestResult::Matched || self == TestResult::Maybe {
+            let other = other();
+            self & other
+        } else {
+            TestResult::NotMatched
+        };
+    }
 }
 
 impl std::ops::BitOr for TestResult {
@@ -79,6 +91,24 @@ impl std::ops::BitOr for TestResult {
     }
 }
 
+impl std::ops::BitAnd for TestResult {
+    type Output = TestResult;
+
+    fn bitand(self, rhs: Self) -> Self::Output {
+        return if self == TestResult::Matched && rhs == TestResult::Matched {
+            TestResult::Matched
+        } else if self == TestResult::Maybe && rhs == TestResult::Maybe {
+            TestResult::Maybe
+        } else if self == TestResult::Matched && rhs == TestResult::Maybe {
+            TestResult::Matched
+        } else if self == TestResult::Maybe && rhs == TestResult::Matched {
+            TestResult::Matched
+        } else {
+            TestResult::NotMatched
+        };
+    }
+}
+
 pub trait FileTypeMatcher {
     /// Tests if the [FileType] magic number can be found in the `bytes` slice.
     fn test(&self, relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult;
@@ -97,6 +127,10 @@ impl FileTypeMatcher for FileType {
             FileType::Opus => opus_test(&relative_position, step, &bytes),
             FileType::Vorbis => vorbis_test(&relative_position, step, &bytes),
             FileType::Mp3 => mp3_test(&relative_position, step, &bytes),
+            FileType::Webp => webp_test(&relative_position, step, &bytes),
+            FileType::Flac => flac_test(&relative_position, step, &bytes),
+            FileType::Matroska => matroska_test(&relative_position, step, &bytes),
+            FileType::Wasm => wasm_test(&relative_position, step, &bytes),
         }
     }
 }
@@ -151,9 +185,33 @@ fn rar5_test(relative_position: &RelativePosition, bytes: &[u8]) -> TestResult {
 }
 
 fn windowing_test(bytes: &[u8], matching: &[u8]) -> TestResult {
-    for window in bytes.windows(matching.len()) {
-        if window == matching {
-            return TestResult::Matched;
+    if bytes.len() < matching.len() {
+        return TestResult::NotMatched;
+    }
+
+    let mut i = 0;
+    loop {
+        if i < (bytes.len() - matching.len()) {
+            let size = i + matching.len();
+            let slice = &bytes[i..size];
+
+            if slice == matching {
+                return TestResult::Matched;
+            } else {
+                let mut any = false;
+                for i in slice {
+                    if *i == matching[0] {
+                        any = true;
+                    }
+                }
+                if !any {
+                    i += (matching.len() - 1);
+                }
+            }
+
+            i += 1
+        } else {
+            break;
         }
     }
 
@@ -246,6 +304,46 @@ fn mp3_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) ->
     return TestResult::NotMatched;
 }
 
+const WEBP_SIGNATURE_1: [u8; 4] = [0x52, 0x49, 0x46, 0x46];
+const WEBP_SIGNATURE_2: [u8; 4] = [0x57, 0x45, 0x42, 0x50];
+fn webp_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        if bytes.len() >= 12 {
+            return slice_test(&bytes, &WEBP_SIGNATURE_1)
+                .and(|| slice_test(&bytes[8..], &WEBP_SIGNATURE_2));
+        }
+    }
+
+    return TestResult::NotMatched;
+}
+
+const FLAC_SIGNATURE: [u8; 4] = [0x66, 0x4C, 0x61, 0x43];
+fn flac_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &FLAC_SIGNATURE);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const MATROSKA_SIGNATURE: [u8; 4] = [0x1A, 0x45, 0xDF, 0xA3];
+fn matroska_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &MATROSKA_SIGNATURE);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const WASM_SIGNATURE: [u8; 4] = [0x00, 0x61, 0x73, 0x6D];
+fn wasm_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &WASM_SIGNATURE);
+    }
+
+    return TestResult::NotMatched;
+}
+
 fn slice_test(bytes: &[u8], matching: &[u8]) -> TestResult {
     if bytes.len() >= matching.len() {
         if &bytes[..matching.len()] == matching {
